@@ -1,8 +1,8 @@
-#define VERSION "1.84a"
+#define VERSION "1.85a"
 
 /*
  *  units, a program for units conversion
- *  Copyright (C) 1996, 1997, 1999, 2000, 2001, 2002, 2003, 2004 
+ *  Copyright (C) 1996, 1997, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006
  *  Free Software Foundation, Inc
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA 02110-1301 USA
  *     
  *  This program was written by Adrian Mariano (adrian@cam.cornell.edu)
  */
@@ -61,12 +62,12 @@ char *mylocale;                 /* Locale in effect (from LOCALE env var) */
 char *numformat = "%.8g";	/* printf format for numeric output */
 char *powerstring = "^";	/* Exponent character used in output */
 int quiet = 0;                  /* Flag for supressing prompting (-q option) */
-int terseout = 0;               /* Flag for terse output (-t option) */
 int unitcheck = 0;              /* Flag for unit checking, set to 1 for 
                                    regular check, set to 2 for verbose check */
-int verbose = 0;                /* Flag for verbose operation */
+int verbose = 1;                /* Flag for output verbosity */
 int strictconvert = 0;          /* Strict conversion (disables reciprocals) */
 int minusminus = 1;             /* Should '-' character give subtraction */
+int oneline = 0;                /* Suppresses the second line of output */
 char *unitsfiles[MAXFILES+1];   /* Null terminated list of units file names */
 char *progname="units";         /* Used in error messages */
 char *queryhave = "You have: "; /* Prompt text for units to convert from */
@@ -1680,11 +1681,12 @@ showfunc(char *havestr, struct unittype *have, struct func *fun)
 	 if (*dimen==0)
 	   dimen = "1";
 	 printf(": conversion requires dimensions of '%s'\n",dimen);
-	 if (verbose) printf("\t%s = ",havestr);
-	 else putchar('\t');
+	 if (verbose==2) printf("\t%s = ",havestr);
+	 else if (verbose==1) putchar('\t');
 	 showunit(have);
-	 if (verbose) printf("\n\t%s = ",dimen);
-	 else printf("\n\t");
+	 if (verbose==2) printf("\n\t%s = ",dimen);
+	 else if (verbose==1) printf("\n\t");
+	 else putchar('\n');
 	 parseunit(&want, dimen, 0, 0);
 	 completereduce(&want);
 	 showunit(&want);
@@ -1696,12 +1698,12 @@ showfunc(char *havestr, struct unittype *have, struct func *fun)
        printf("Function evaluation error (bad function definition)\n");
      return 1;
    }
-   if (verbose)
+   if (verbose==2)
      printf("\t%s = %s(", havestr, fun->inverse.param);
-   else 
-     if (!terseout) putchar('\t');
+   else if (verbose==1) 
+     putchar('\t');
    showunit(have);
-   if (verbose)
+   if (verbose==2)
      putchar(')');
    putchar('\n');
    return 0;
@@ -1733,20 +1735,28 @@ showanswer(char *havestr,struct unittype *have,
         *dest=0;
         if (strictconvert || compareunits(&invhave, want, ignore_dimless)){
 	  printf("conformability error\n");
-	  if (verbose) printf("\t%s = ",havestr);
-	  else putchar('\t');
+	  if (verbose==2) 
+	    printf("\t%s = ",havestr);
+	  else if (verbose==1)
+	    putchar('\t');
 	  showunit(have);
-	  if (verbose) printf("\n\t%s = ",wantstr);
-	  else printf("\n\t");
+	  if (verbose==2) 
+	    printf("\n\t%s = ",wantstr);
+	  else if (verbose==1)
+	    printf("\n\t");
+	  else
+	    putchar('\n');
 	  showunit(want);
 	  putchar('\n');
 	  return -1;
         }
-        printf("\treciprocal conversion\n");
+	if (verbose>0)
+	  putchar('\t');
+        printf("reciprocal conversion\n");
         have=&invhave;
         doingrec=1;
    } 
-   if (verbose) {
+   if (verbose==2) {
      if (strchr("0123456789.",wantstr[0]))
        sep=" *";
      else 
@@ -1761,15 +1771,29 @@ showanswer(char *havestr,struct unittype *have,
        right="";
      }
    }   
-   if (verbose) printf("\t%s%s%s = ",left,havestr,right);
-   else if (!terseout) printf("\t* ");
+
+   /* Print the first line of output. */
+
+   if (verbose==2) 
+     printf("\t%s%s%s = ",left,havestr,right);
+   else if (verbose==1)
+     printf("\t* ");
    printf(numformat, have->factor / want->factor);
-   if (!terseout){
-     if (verbose) 
-       printf("%s %s\n\t%s%s%s = (1 / ",sep,wantstr,left,havestr,right);
-     else printf("\n\t/ ");
+   if (verbose==2) {
+     printf("%s %s", sep, wantstr);
+   }
+
+   /* Print the second line of output. */
+
+   if (!oneline){
+     if (verbose==2) 
+       printf("\n\t%s%s%s = (1 / ",left,havestr,right);
+     else if (verbose==1)
+       printf("\n\t/ ");
+     else 
+       putchar('\n');
      printf(numformat, want->factor / have->factor);
-     if (verbose) printf(")%s %s",sep,wantstr);
+     if (verbose==2) printf(")%s %s",sep,wantstr);
    }
    putchar('\n');
    return 0;
@@ -1852,8 +1876,6 @@ checkfunc(struct func *infunc, int verbose)
    function definitions are valid and have correct inverses.  A message is
    printed for every unit that does not reduce to primitive units.
 
-   This function has the side effect of defining all primitive units
-   in the database to have the value "1".
 */
 
 
@@ -2059,17 +2081,19 @@ usage()
     -h, --help          print this help and exit\n\
     -c, --check         check that all units reduce to primitive units\n\
         --check-verbose like --check, but lists units as they are checked\n\
-                          so you can find units that cause endless loops\n\
+        --verbose-check   so you can find units that cause endless loops\n\
     -e, --exponential   exponential format output\n\
-    -f, --file          specify units data files (-f '' loads default file)\n\
+    -f, --file          specify a units data files (-f '' loads default file)\n\
     -m, --minus         make - into a subtraction operator (default)\n\
     -o, --output-format specify printf numeric output format\n\
     -p, --product       make - into a product operator\n\
     -q, --quiet         supress prompting\n\
         --silent        same as --quiet\n\
     -s, --strict        suppress reciprocal unit conversion (e.g. Hz<->s)\n\
-    -t, --terse         print terse conversion factor output\n\
     -v, --verbose       print slightly more verbose output\n\
+        --compact       suppress printing of tab, '*', and '/' character\n\
+    -1, --one-line      suppress the second line of output\n\
+    -t, --terse         terse output (--strict --compact --quiet --one-line)\n\
     -V, --version       print version number and exit\n\n\
 Report bugs to adrian@cam.cornell.edu.\n\n", stdout);
    exit(0);
@@ -2260,7 +2284,7 @@ findunitsfile()
 }
    
 
-char *shortoptions = "Vvqechstf:o:mp";
+char *shortoptions = "Vvqechstf:o:mp1";
 
 struct option longoptions[] = {
   {"version", no_argument, 0, 'V'},
@@ -2270,14 +2294,16 @@ struct option longoptions[] = {
   {"check", no_argument, &unitcheck, 1},
   {"check-verbose", no_argument, &unitcheck, 2},
   {"verbose-check", no_argument, &unitcheck, 2},
-  {"verbose", no_argument, &verbose, 1},
+  {"verbose", no_argument, &verbose, 2},
   {"file", required_argument, 0, 'f'},
   {"output-format", required_argument, 0, 'o'},
   {"help",no_argument,0,'h'},
   {"strict",no_argument,&strictconvert, 1},
-  {"terse",no_argument, &terseout, 1},
+  {"terse",no_argument, 0, 't'},
+  {"compact", no_argument, &verbose, 0},
   {"minus", no_argument, &minusminus, 1},
   {"product", no_argument, &minusminus, 0},
+  {"one-line", no_argument, &oneline, 1},
   {0,0,0,0} };
 
 /* Process the args.  Returns 1 if interactive mode is desired, and 0
@@ -2303,7 +2329,10 @@ processargs(int argc, char **argv, char **from, char **to)
 	    minusminus = 0;
 	    break;
          case 't':
- 	    terseout = 1;
+	    oneline = 1;
+	    quiet = 1;
+	    strictconvert = 1;
+	    verbose = 0;
             break;
          case 'o':
             numformat = optarg;
@@ -2334,8 +2363,11 @@ processargs(int argc, char **argv, char **from, char **to)
             strictconvert = 1;
             break;
          case 'v':
-            verbose = 1;
+            verbose = 2;
             break;
+         case '1':
+          oneline = 1;
+          break;
 	 case 'V':
  	    printversion();
 	    exit(3);
@@ -2349,10 +2381,6 @@ processargs(int argc, char **argv, char **from, char **to)
             helpmsg();
       } 
    }
-   if (terseout){
-     strictconvert = 1;
-     verbose = 0;
-   }
    if (optind == argc - 2) {
       quiet=1;
       *from = argv[optind];
@@ -2454,7 +2482,7 @@ prompt type in the units you want to convert from.  At the '%s'\n\
 prompt enter the units to convert to.  \n\
 \n\
 Examples:\n\
-%s6 inches\t%stempF(75)\t%s2 btu + 450 ft-lbf\n\
+%s6 inches\t%stempF(75)\t%s2 btu + 450 ft lbf\n\
 %scm\t\t%stempC\t\t%s(kg^2/s)/(day lb/m^2)\n\
 \t* 15.24\t\t\t23.889\t\t\t* 1.0660684e+08\n\
 \t/ 0.065\t\t\t\t\t\t/ 9.3802611e-09\n\
@@ -2560,7 +2588,7 @@ main(int argc, char **argv)
      printf("%d units, %d prefixes, %d nonlinear units\n\n", unitcount, prefixcount,
      funccount);
    if (unitcheck) {
-      checkunits(unitcheck==2 || verbose);
+      checkunits(unitcheck==2 || verbose==2);
       exit(0);
    }
 
