@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *     
  *  This program was written by Adrian Mariano (adrian@cam.cornell.edu)
  */
@@ -22,6 +22,12 @@
 #include <math.h>
 #include <errno.h>
 
+/* Apparently popen and pclose require leading _ under windows */
+#if defined(_MSC_VER) || defined(__MINGW32__)
+#  define popen(c,m) _popen(c,m)
+#  define pclose(p) _pclose(p)
+#endif
+
 #ifdef STRINGS_H
 #  include <strings.h>
 #else
